/***************************************************************************
  begin                : Fri Nov 1 2002
  copyright            : (C) 2002 by Christian Hubinger
  email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFPORTWIDGET_H
#define KMFPORTWIDGET_H

#include <qwidget.h>
#include <kdemacros.h>
#include "kmyfirewallportwidget.h"

/**Widget for input of portnumbers, portranges or names
  *@author Christian Hubinger
  */
  
namespace KMF {
class KMFError;

class KDE_EXPORT KMFPortWidget : public KMyFirewallPortWidget {
	Q_OBJECT
public:
	KMFPortWidget( QWidget *parent = 0, const char *name = 0 );
	~KMFPortWidget();
	KMFError* getPortString( QString* value );
	void loadPortString( QString& );
	void reset();
private:
	KMFError *m_err;

signals:
	void sigMultiPortChanged( bool );
};
}
#endif
